@@ -1,11 +1,12 @@
 """Tests related to our logging/verbosity setup."""
+from __future__ import annotations
 
-import os
-from typing import List, Tuple
+from pathlib import Path
 
 import pytest
 
 from ansiblelint.testing import run_ansible_lint
+from ansiblelint.text import strip_ansi_escape
 
 
 # substrs is a list of tuples, where:
@@ -14,82 +15,79 @@ from ansiblelint.testing import run_ansible_lint
 @pytest.mark.parametrize(
     ("verbosity", "substrs"),
     (
-        (
+        pytest.param(
             "",
             [
                 ("WARNING  Listing 1 violation(s) that are fatal", False),
                 ("DEBUG ", True),
                 ("INFO ", True),
             ],
+            id="default",
         ),
-        (
+        pytest.param(
             "-q",
             [
                 ("WARNING ", True),
                 ("DEBUG ", True),
                 ("INFO ", True),
             ],
+            id="q",
         ),
-        (
+        pytest.param(
             "-qq",
             [
                 ("WARNING ", True),
                 ("DEBUG ", True),
                 ("INFO ", True),
             ],
+            id="qq",
         ),
-        (
+        pytest.param(
             "-v",
             [
                 ("WARNING  Listing 1 violation(s) that are fatal", False),
                 ("INFO     Set ANSIBLE_LIBRARY=", False),
                 ("DEBUG ", True),
             ],
+            id="v",
         ),
-        (
+        pytest.param(
             "-vv",
             [
-                ("DEBUG    Loading custom .yamllint config file,", False),
                 ("WARNING  Listing 1 violation(s) that are fatal", False),
                 ("INFO     Set ANSIBLE_LIBRARY=", False),
-                ("DEBUG    Effective yamllint rules used", False),
             ],
+            id="really-loquacious",
         ),
-        (
-            "-vvvvvvvvvvvvvvvvvvvvvvvvv",
+        pytest.param(
+            "-vv",
             [
-                ("DEBUG    Loading custom .yamllint config file,", False),
                 ("WARNING  Listing 1 violation(s) that are fatal", False),
                 ("INFO     Set ANSIBLE_LIBRARY=", False),
-                ("DEBUG    Effective yamllint rules used", False),
             ],
+            id="vv",
         ),
     ),
-    ids=(
-        "default verbosity",
-        "quiet",
-        "really quiet",
-        "loquacious",
-        "really loquacious",
-        'really loquacious but with more "v"s -- same as -vv',
-    ),
 )
-def test_default_verbosity(verbosity: str, substrs: List[Tuple[str, bool]]) -> None:
+def test_verbosity(
+    verbosity: str,
+    substrs: list[tuple[str, bool]],
+    project_path: Path,
+) -> None:
     """Checks that our default verbosity displays (only) warnings."""
     # Piggyback off the .yamllint in the root of the repo, just for testing.
     # We'll "override" it with the one in the fixture, to produce a warning.
-    cwd = os.path.realpath(
-        os.path.join(os.path.dirname(os.path.realpath(__file__)), "..")
-    )
-
-    fakerole = os.path.join("test", "fixtures", "verbosity-tests")
+    fakerole = Path() / "test" / "fixtures" / "verbosity-tests"
 
     if verbosity:
-        result = run_ansible_lint(verbosity, fakerole, cwd=cwd)
+        result = run_ansible_lint(verbosity, str(fakerole), cwd=project_path)
     else:
-        result = run_ansible_lint(fakerole, cwd=cwd)
+        result = run_ansible_lint(str(fakerole), cwd=project_path)
 
-    for (substr, invert) in substrs:
+    result.stderr = strip_ansi_escape(result.stderr)
+    result.stdout = strip_ansi_escape(result.stdout)
+    assert result.returncode == 2, result
+    for substr, invert in substrs:
         if invert:
             assert substr not in result.stderr, result.stderr
         else:
